sonote — 실시간 회의 전사

🎙
sonote
시작하는 중...
잠시 후 재시도합니다...

# sonote

자동 스크롤 ON
과거 세션을 보고 있습니다
재연결 중 WS
마이크
장치 로딩 중...
회의 세션 준비 중... 00:00:00 0 세그먼트

## 화자 등록

## 도메인 키워드 관리

🎙
회의 전사 준비
마이크를 선택하고 녹음을 시작하세요
음성 인식 중...
설정
오디오
마이크 장치
녹음 옵션
화자 분리
발화자를 자동으로 구분합니다
미디어 자동 음소거
녹음 시 시스템 오디오를 음소거합니다
트레이 최소화
닫기 시 시스템 트레이로 최소화
후처리
후처리 엔진
알림
Discord Webhook URL

## 회의를 종료할까요?

지금까지 기록된 모든 전사 내역을
안전하게 저장하고 세션을 종료합니다.

## 세션을 삭제할까요?

이 세션의 모든 전사 기록이 영구적으로 삭제됩니다.